@@ -44,10 +44,10 @@ def create_requirements_txt(root_path: os.PathLike, destination: os.PathLike = N
         optional_path = f" --savepath {os.path.join(destination, 'requirements.txt')}" if destination else ""
         if update:
             subprocess.check_output(
-                f'pipreqs --force {root_path}{optional_path}', shell=True)
+                f'pipreqs --encoding=utf8 --force {root_path}{optional_path}', shell=True)
         else:
             subprocess.check_output(
-                f'pipreqs {root_path}{optional_path}', shell=True)
+                f'pipreqs --encoding=utf8 {root_path}{optional_path}', shell=True)
     except subprocess.CalledProcessError:
         # pipreqs throws a SyntaxError if it encounters a non-ASCII character
         # One reason may be that the user is not in a valid dash app directory
